@@ -46,7 +46,7 @@ from ldict.core.inspection import extract_implicit_input, extract_output, extrac
 from ldict.core.inspection import extract_input
 from ldict.exception import InconsistentLange, UndefinedSeed, DependenceException
 from ldict.lazyval import LazyVal
-from ldict.parameter.base import AbstractLet
+from ldict.parameter.base.abslet import AbstractLet
 
 
 def handle_dict(data, dictlike, rnd):
